@@ -177,6 +177,8 @@ class Database(object):
         self.dbname = validate_dbname(dbname)
         self.server = server
         self.res = server.res.clone()
+        if "/" in dbname:
+            self.res.client.safe = ":/%"
         self.res.update_uri('/%s' % url_quote(dbname, safe=":"))
     
     def __repr__(self):
@@ -719,6 +721,8 @@ class ViewResults(object):
     @property
     def total_rows(self):
         """ return number of total rows in the view """
+        self._fetch_if_needed()
+        # reduce case, count number of lines
         if self._total_rows is None:
             return self.count()
         return self._total_rows
