@@ -14,6 +14,7 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
+""" properties used by Document object """
 
 from calendar import timegm
 import decimal
@@ -306,6 +307,9 @@ class DateTimeProperty(Property):
     def to_json(self, value):
         if self.auto_now:
             value = self.now()
+        
+        if value is None:
+            return value
         return value.replace(microsecond=0).isoformat() + 'Z'
 
     data_type = datetime.datetime
@@ -335,6 +339,8 @@ class DateProperty(DateTimeProperty):
         return value
 
     def to_json(self, value):
+        if value is None:
+            return value
         return value.isoformat()
 
 class TimeProperty(DateTimeProperty):
@@ -360,6 +366,8 @@ class TimeProperty(DateTimeProperty):
         return value
 
     def to_json(self, value):
+        if value is None:
+            return value
         return value.replace(microsecond=0).isoformat()
         
 
@@ -523,6 +531,7 @@ class LazyDict(dict):
             self.doc[key] = {}
             value = LazyDict(value,  self.doc[key])
         elif isinstance(value, list):
+            self.doc[key] = []
             value = LazyList(value,  self.doc[key])
         else:
             self.doc.update({key: value_to_json(value) })
@@ -726,4 +735,4 @@ def list_to_python(value):
     
 def dict_to_python(value):
     """ convert a json object values to python dict """
-    return dict([(k, value_to_python(v)) for k, v in value.iteritems()])
\ No newline at end of file
+    return dict([(k, value_to_python(v)) for k, v in value.iteritems()])
